@@ -7,7 +7,7 @@
 import os, hashlib
 
 
-class Encryption:
+class Encryption(object):
     """All static methods, there is no need to initialize the class"""
 
     @staticmethod
