@@ -42,10 +42,9 @@ class EncryptionTestCase(unittest.TestCase):
 
 from database import Database
 from sqlalchemy import Column, Integer, String
-class Test(Database.Base):
+class Test:
     """This is an user defined model"""
-    __tablename__ = 'test'
-    id = Column(Integer, primary_key = True)
+    __metaclass__ = Database.DefaultMeta
     email = Column(String(70))
 class DatabaseTestCase(unittest.TestCase):
     """Test database.py"""
